'use client';

import {
  Box,
  Button,
  Center,
  Text,
  useColorModeValue,
} from '@chakra-ui/react';
import { ChevronDownIcon, ChevronUpIcon } from '@chakra-ui/icons';
import { useState } from 'react';

interface BlogPostContentProps {
  excerpt: string;
}

export default function BlogPostContent({ excerpt }: BlogPostContentProps) {
  const [isExpanded, setIsExpanded] = useState(false);
  const bg = useColorModeValue('white', 'gray.800');

  const toggleExcerpt = () => setIsExpanded((prev) => !prev);

  return (
    <Box position="relative">
      <Box
        maxH={isExpanded ? 'none' : '300px'}
        overflow="hidden"
        position="relative"
      >
        <Text
          whiteSpace="pre-line"
          overflowWrap="break-word"
          textAlign="justify"
          transition="max-height 0.3s ease-in-out"
        >
          {excerpt}
        </Text>

        {!isExpanded && (
          <Box
            position="absolute"
            bottom="0"
            left="0"
            right="0"
            height="80px"
            bgGradient={`linear(to-t, ${bg}, transparent)`}
          />
        )}
      </Box>

      {excerpt.length > 300 && (
        <Center mt={4}>
          <Button
            onClick={toggleExcerpt}
            rightIcon={isExpanded ? <ChevronUpIcon /> : <ChevronDownIcon />}
            colorScheme="blue"
            variant="outline"
            size="sm"
          >
            {isExpanded ? 'Show less' : 'Read more'}
          </Button>
        </Center>
      )}
    </Box>
  );
}
